<?php

namespace Lavalite\Blog\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Lavalite\Blog\Http\Requests\BlogCategoryRequest;
use Lavalite\Blog\Interfaces\BlogCategoryRepositoryInterface;
use Lavalite\Blog\Models\BlogCategory;

/**
 * Resource controller class for blog_category.
 */
class BlogCategoryResourceController extends BaseController
{

    /**
     * Initialize blog_category resource controller.
     *
     * @param type BlogCategoryRepositoryInterface $blog_category
     *
     * @return null
     */
    public function __construct(BlogCategoryRepositoryInterface $blog_category)
    {
        parent::__construct();
        $this->repository = $blog_category;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Lavalite\Blog\Repositories\Criteria\BlogCategoryResourceCriteria::class);
    }

    /**
     * Display a list of blog_category.
     *
     * @return Response
     */
    public function index(BlogCategoryRequest $request)
    {

        if ($this->response->typeIs('json')) {
            $pageLimit = $request->input('pageLimit');
            $data      = $this->repository
                ->setPresenter(\Lavalite\Blog\Repositories\Presenter\BlogCategoryListPresenter::class)
                ->getDataTable($pageLimit);
            return $this->response
                ->data($data)
                ->output();
        }

        $blog_categories = $this->repository->paginate();

        return $this->response->title(trans('blog::blog_category.names'))
            ->view('blog::blog_category.index', true)
            ->data(compact('blog_categories'))
            ->output();
    }

    /**
     * Display blog_category.
     *
     * @param Request $request
     * @param Model   $blog_category
     *
     * @return Response
     */
    public function show(BlogCategoryRequest $request, BlogCategory $blog_category)
    {

        if ($blog_category->exists) {
            $view = 'blog::blog_category.show';
        } else {
            $view = 'blog::blog_category.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('blog::blog_category.name'))
            ->data(compact('blog_category'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new blog_category.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(BlogCategoryRequest $request)
    {

        $blog_category = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('blog::blog_category.name')) 
            ->view('blog::blog_category.create', true) 
            ->data(compact('blog_category'))
            ->output();
    }

    /**
     * Create new blog_category.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(BlogCategoryRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $blog_category                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('blog::blog_category.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('blog/blog_category/' . $blog_category->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/blog/blog_category'))
                ->redirect();
        }

    }

    /**
     * Show blog_category for editing.
     *
     * @param Request $request
     * @param Model   $blog_category
     *
     * @return Response
     */
    public function edit(BlogCategoryRequest $request, BlogCategory $blog_category)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('blog::blog_category.name'))
            ->view('blog::blog_category.edit', true)
            ->data(compact('blog_category'))
            ->output();
    }

    /**
     * Update the blog_category.
     *
     * @param Request $request
     * @param Model   $blog_category
     *
     * @return Response
     */
    public function update(BlogCategoryRequest $request, BlogCategory $blog_category)
    {
        try {
            $attributes = $request->all();

            $blog_category->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('blog::blog_category.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('blog/blog_category/' . $blog_category->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('blog/blog_category/' . $blog_category->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the blog_category.
     *
     * @param Model   $blog_category
     *
     * @return Response
     */
    public function destroy(BlogCategoryRequest $request, BlogCategory $blog_category)
    {
        try {

            $blog_category->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('blog::blog_category.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('blog/blog_category'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('blog/blog_category/' . $blog_category->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple blog_category.
     *
     * @param Model   $blog_category
     *
     * @return Response
     */
    public function delete(BlogCategoryRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('blog::blog_category.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('blog/blog_category'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/blog/blog_category'))
                ->redirect();
        }

    }

    /**
     * Restore deleted blog_categories.
     *
     * @param Model   $blog_category
     *
     * @return Response
     */
    public function restore(BlogCategoryRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('blog::blog_category.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/blog/blog_category'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/blog/blog_category/'))
                ->redirect();
        }

    }

}
